function L = l_taps(u,a,n)
% Find the regressor matrix for the Laguerre problem
%    a is the laguerre parameter
%    n is the order of the laguerre system
%    u is the input

% Create state transition matrix and input matrix
if n == 1,
 A = a;
else
 A = [a , 0 ; (1-a^2) ,a];
 if n > 2,
  for i = 3:n,
   A = [A zeros(i-1,1) ; (-a)*A(i-1,1:i-2) (1-a^2) a];
  end
 end
end
B = zeros(n,1);
for i = 1:n,
 B(i) = (-a)^(i-1);
end
B = B * sqrt(1-a^2);
 
C=eye(n);

%Compute teta coefficients

% Compute the laguerre filter responses
L = dlsim(A,B,C,zeros(n,1),u);

L = [u , L];
